@@ -1,16 +1,16 @@
 ######################################################################
 # antispamwiki.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: antispamwiki.inc.pl,v 1.48 2011/05/04 07:26:50 papu Exp $
+# $Id: antispamwiki.inc.pl,v 1.380 2012/01/31 10:11:55 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-rc6 $$
+# "PyukiWiki" version 0.2.0-p1 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2010 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2010 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -37,31 +37,49 @@
 # ͭ¡ʣ֡
 $AntiSpamWiki::expire=1*60*60
 	if(!defined($AntiSpamWiki::expire));
-
+#
+# û񤭹߻֡ʣá
+$AntiSpamWiki::mintime=5
+	if(!defined($AntiSpamWiki::mintime));
+#
 %::antispamwiki_cookie;
-$::antispamwiki_cookie="PyukiWikiAntiSpamWiki_"
-				. length($::basepath);
+$::antispamwiki_cookie="PAW_"
+				. &dbmname($::basepath);
+$::antispamwiki_cookie_name="t";
+$::antispamwiki_cookie_expire=60*60*60;
+######################################################################
 
-# Initlize
+# Initlize												# comment
 
 sub plugin_antispamwiki_init {
+
+#	return('init'=>0)
+#		if($::form{cmd}!~/edit|article|attach|bugtrack|comment|vote/);
+
 	my $stat=0;
 	%::antispamwiki_cookie=();
 	%::antispamwiki_cookie=&getcookie($::antispamwiki_cookie,%::antispamwiki_cookie);
 	my $time=time;
-	if($::antispamwiki_cookie{time} eq '') {
+	if($::antispamwiki_cookie{$::antispamwiki_cookie_name} eq '') {
 		$stat=1;
-	} elsif($::antispamwiki_cookie{time}+0+$AntiSpamWiki::expire < $time) {
+	} elsif($::antispamwiki_cookie{$::antispamwiki_cookie_name}+0+$AntiSpamWiki::expire < $time) {
+		$stat=-1;
+	} elsif($time-$::antispamwiki_cookie{$::antispamwiki_cookie_name}+0 < $AntiSpamWiki::mintime) {
 		$stat=-1;
 	}
+$::debug.="now:$time, cookie:$::antispamwiki_cookie{$::antispamwiki_cookie_name}\n";
 	if($stat+0 ne 0) {
-		if($::form{mymsg} ne '' || $ENV{REQUEST_METHOD}=~/[Pp][Oo][Ss][Tt]/) {
+		if($::form{mymsg} ne '' ||$::form{msg} ne '') {
 			$::form{cmd}="read";
 			$::form{mypage}=$::FrontPage;
 		}
 	}
-	my $js=qq(<script type="text/javascript">@{[!$::is_xhtml ? "<!--\n" : '']}document.cookie="$::antispamwiki_cookie=time%3a$time; path=$::basepath";@{[!$::is_xhtml ? '//-->' : '']}</script>\n);
-	return('init'=>1, 'header'=>$js);
+	$::antispamwiki_cookie{$::antispamwiki_cookie_name}=$time;
+	&setcookie($::antispamwiki_cookie,$::antispamwiki_cookie_expire,%::antispamwiki_cookie);
+
+#	my $js=qq(<script type="text/javascript"><!--\nd.cookie="$::antispamwiki_cookie=$::antispamwiki_cookie_name%3a$time; path=$::basepath";\n//--></script>\n);
+	return('init'=>1);
+#	return('init'=>1, 'header'=>$js);
 }
 1;
 __DATA__
@@ -70,7 +88,7 @@ sub plugin_antispamwiki_setup {
 	'ja'=>'Wikiѥߥɻ',
 	'en'=>'Anti Spam for WikiPlugin',
 	'override'=>'',
-	'url'=>'http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/ExPlugin/antispamwiki/'
+	'url'=>'http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/ExPlugin/antispamwiki/'
 	);
 }
 __END__
@@ -101,11 +119,13 @@ none
 
 =item PyukiWiki/Plugin/ExPlugin/antispamwiki
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/ExPlugin/antispam/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/ExPlugin/antispam/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/antispamwiki.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/antispamwiki.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/lib/antispamwiki.inc.pl?view=log>
 
 =back
 
@@ -119,17 +139,17 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2010 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2010 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
