@@ -1,16 +1,16 @@
 ######################################################################
 # adminedit.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: adminedit.inc.pl,v 1.97 2011/05/04 07:26:50 papu Exp $
+# $Id: adminedit.inc.pl,v 1.480 2012/03/01 08:41:56 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
-# Author: Nekyo
-# Copyright (C) 2004-2011 by Nekyo.
+# "PyukiWiki" version 0.2.0-p2 $$
+# Author: Nekyo http://nekyo.qp.land.to/
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -27,7 +27,7 @@ sub plugin_adminedit_action {
 			$body .= qq(<p><strong>$::resource{edit_plugin_cantchange}</strong></p>);
 		} else {
 			$body .= qq(<p><strong>$::resource{adminedit_plugin_passwordneeded}</strong></p>);
-			# 2005.11.2 pochi: ҏW\ (thanks Walrus)
+			# 2005.11.2 pochi: ҏW\ (thanks Walrus)	# comment
 			my $pagemsg;
 			if ($::form{mypart} =~ /^\d+$/ and $::form{mypart}) {
 				my $mymsg = (&read_by_part($page))[$::form{mypart} - 1];
@@ -70,11 +70,13 @@ The page name must be encoded.
 
 =item PyukiWiki/Plugin/Admin/adminedit
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Nanami/adminedit/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Nanami/adminedit/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/adminedit.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/adminedit.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/adminedit.inc.pl?view=log>
 
 =back
 
@@ -88,17 +90,17 @@ L<http://nekyo.qp.land.to/>
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2004-2011 by Nekyo.
+Copyright (C) 2004-2012 by Nekyo.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
