@@ -1,16 +1,16 @@
 ######################################################################
 # aname.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: aname.inc.pl,v 1.92 2011/05/04 07:26:50 papu Exp $
+# $Id: aname.inc.pl,v 1.505 2012/03/18 11:23:51 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
-# Author: Nekyo
-# Copyright (C) 2004-2011 by Nekyo.
+# "PyukiWiki" ver 0.2.0-p3 $$
+# Author: Nekyo http://nekyo.qp.land.to/
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -77,11 +77,13 @@ An anchor link, set as the position.
 
 =item PyukiWiki/Plugin/Standard/aname
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/aname/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/aname/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/aname.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/aname.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/aname.inc.pl?view=log>
 
 =back
 
@@ -95,17 +97,17 @@ L<http://nekyo.qp.land.to/>
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2004-2011 by Nekyo.
+Copyright (C) 2004-2012 by Nekyo.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
