@@ -1,16 +1,16 @@
 ######################################################################
 # back.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: back.inc.pl,v 1.33 2010/12/14 22:20:00 papu Exp $
+# $Id: back.inc.pl,v 1.459 2012/03/18 11:23:51 papu Exp $
 #
-# "PyukiWiki" version 0.1.8 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2010 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2010 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -21,9 +21,14 @@ $back::allowpagelink=0
 	if(!defined($back::allowpagelink));
 $back::allowjavascript=1
 	if(!defined($back::allowjavascript));
+$back::blacket=1
+	if(!defined($back::blacket));
+######################################################################
 
 use strict;
 
+$::back::count;
+
 sub plugin_back_convert {
 	my($str,$align,$hr,$link)=split(/,/,shift);
 	my $body;
@@ -41,18 +46,25 @@ sub plugin_back_convert {
 	}
 	if($link eq "") {
 		if($back::allowjavascript eq 1) {
+			$::back::count+=0;
+			$::back::count++;
 			$body=<<EOM;
-<script type="text/javascript">@{[!$::is_xhtml ? "<!--\n" : '']}
-if(history.length != 0) {
-	document.write('$hr<div align="$align"><a href="javascript:history.go(-1)" title="$str">$str</a></div>');
-}
-@{[!$::is_xhtml ? '//-->' : '']}</script>
+<span id="back_$::back::count"></span>
+<script type="text/javascript"><!--
+if(history.length!=0){d.getElementById("back_$::back::count").innerHTML='$hr<div align="$align">@{[$back::blacket eq 1 ? '[' : '']}<a href="javascript:history.go(-1)" title="$str">$str</a>@{[$back::blacket eq 1 ? ']' : '']}</div>';}
+//--></script>
+<noscript>
+$hr
+<div align="$align">
+@{[$back::blacket eq 1 ? '[' : '']}<a href="$ENV{HTTP_REFERER}" title="$str">$str</a>@{[$back::blacket eq 1 ? ']' : '']}
+</div>
+</noscript>
 EOM
 		} elsif($ENV{HTTP_REFERER} ne '') {
 			$body=<<EOM;
 $hr
 <div align="$align">
-<a href="$ENV{HTTP_REFERER}" title="$str">$str</a>
+@{[$back::blacket eq 1 ? '[' : '']}<a href="$ENV{HTTP_REFERER}" title="$str">$str</a>@{[$back::blacket eq 1 ? ']' : '']}
 </div>
 EOM
 		} else {
@@ -77,7 +89,7 @@ back.inc.pl - PyukiWiki Plugin
 
 =head1 SYNOPSIS
 
- #back( [[Display string] [,[left| center| right] [,[0| 1] [,[Back to link] ]]]] ) 
+ #back( [[Display string] [,[left| center| right] [,[0| 1] [,[Back to link] ]]]] )
 
 =head1 DESCRIPTION
 
@@ -136,11 +148,13 @@ It does not display, when the history of JavaScript does not exist.
 
 =item PyukiWiki/Plugin/Standard/back
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/back/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/back/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/back.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/back.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/back.inc.pl?view=log>
 
 =back
 
@@ -154,17 +168,17 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2010 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2010 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
