@@ -1,16 +1,16 @@
 ######################################################################
 # comment.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: comment.inc.pl,v 1.94 2011/05/04 07:26:50 papu Exp $
+# $Id: comment.inc.pl,v 1.479 2012/03/01 08:41:56 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
-# Author: Nekyo
-# Copyright (C) 2004-2011 by Nekyo.
+# "PyukiWiki" version 0.2.0-p2 $$
+# Author: Nekyo http://nekyo.qp.land.to/
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -20,45 +20,44 @@
 # v 0.0.2 - 2004/10/28 Tnx:Birgus-Latro
 # v 0.0.1 - ProtoType
 ######################################################################
-
-use strict;
-
 # Υեޥå
 $comment::format = "\x08MSG\x08 -- \x08NAME\x08 \x08NOW\x08"
 	if(!defined($comment::format));
-
+#
 # ̾ʤǽʤ
 $comment::noname = 1
 	if(!defined($comment::noname));
-
+#
 # ʸܤƤʤ票顼
 $comment::nodata = 1
 	if(!defined($comment::nodata));
-
-# ȤΥƥȥꥢɽ 
+#
+# ȤΥƥȥꥢɽ
 $comment::size_msg = 40
 	if(!defined($comment::size_name));
-
-# Ȥ̾ƥȥꥢɽ 
+#
+# Ȥ̾ƥȥꥢɽ
 $comment::size_name = 10
 	if(!defined($comment::size_name));
-
+#
 # Ȥ̾եޥå
 $comment::format_name = "\'\'[[\$1>$::resource{profile_page}/\$1]]\'\'"
 	if(!defined($comment::format_name));
-
+#
 # Ȥեޥå
 $comment::format_msg = q{$1}
 	if(!defined($comment::format_msg));
-
+#
 # Ȥեޥå (&new ǧǤ뤳)
 $comment::format_now = "Y-m-d(lL) H:i:s"
 	if(!defined($comment::format_now));
+######################################################################
 
+use strict;
 
 sub plugin_comment_action {
-	&::spam_filter($::form{mymsg}, 2);
-	&::spam_filter($::form{myname}, 0);
+	&::spam_filter($::form{mymsg}, 2, $::chk_article_uri_count, $::chk_article_mail_count);
+	&::spam_filter($::form{myname}, 0, $::chk_article_uri_count, $::chk_article_mail_count);
 
 	if (($::form{mymsg} =~ /^\s*$/ && $comment::nodata eq 1)
 	 || ($::form{myname} =~ /^\s*$/ && $comment::noname eq 1)
@@ -231,11 +230,13 @@ do error of no comment
 
 =item PyukiWiki/Plugin/Standard/comment
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/comment/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/comment/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/comment.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/comment.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/comment.inc.pl?view=log>
 
 =back
 
@@ -249,17 +250,17 @@ L<http://nekyo.qp.land.to/>
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2004-2011 by Nekyo.
+Copyright (C) 2004-2012 by Nekyo.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
