@@ -1,15 +1,15 @@
 ######################################################################
 # counter.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: counter.inc.pl,v 1.95 2011/04/13 08:42:38 papu Exp $
+# $Id: counter.inc.pl,v 1.356 2011/12/31 13:06:10 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p5 $$
+# "PyukiWiki" version 0.2.0 $$
 # Author: Nekyo
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 by Nekyo.
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
 # License: GPL2 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
@@ -29,7 +29,7 @@
 use strict;
 use Nana::File;
 
-# mod_perlǼ¹Բǽ
+# mod_perlǼ¹Բǽ										# comment
 $::functions{"plugin_counter_do"} = \&plugin_counter_do;
 
 %::counter_loaded;
@@ -97,8 +97,9 @@ sub plugin_counter_do {
 	my($page,$rw)=@_;
 	$rw="r" if($rw=~/[Rr]/);
 	my %counter = %default;
-	my $file = $::counter_dir . "/" . &encode($page) . $::counter_ext;
 	my $hex=&dbmname($page);
+	my $new=$hex;
+	my $file = $::counter_dir . "/" . $new . $::counter_ext;
 	my ($mday, $mon, $year) = (localtime)[3..5];
 	$year += 1900;
 	$mon += 1;
@@ -124,9 +125,16 @@ sub plugin_counter_do {
 		%counter=$::counter_loaded->{$hex};
 	} else {
 		my $counters=Nana::File::lock_fetch($file);
+		if($counters eq '') {
+			my $old=&encode($page);
+			my $oldfile = $::counter_dir . "/" . $old . $::counter_ext;
+			$counters=Nana::File::lock_fetch($oldfile);
+			$modify = 1;
+			Nana::File::lock_delete($oldfile);
+		}
 		my @tmp=split(/\n/,$counters);
 		if($counters=~/date\t/) {
-			$counter{version}=2;		# ܺ٥
+			$counter{version}=2;		# ܺ٥		# comment
 			foreach(@tmp) {
 				chomp;
 				my($localtime,$datecount)=split(/\t/,$_);
@@ -138,10 +146,10 @@ sub plugin_counter_do {
 		} else {
 			my @loadkeys;
 			if($tmp[1]=~/[.\/]/ && $tmp[0]=~/\//) {
-				$counter{version}=1;	# ʥ
+				$counter{version}=1;	# ʥ	# comment
 				@loadkeys=@keys;
 			} else {
-				$counter{version}=0;	# 줿
+				$counter{version}=0;	# 줿	# comment
 				@loadkeys=keys %default;
 			}
 			my $max=0;
@@ -160,7 +168,7 @@ sub plugin_counter_do {
 		}
 		if ($counter{date} ne $default{date}) {
 			$modify = 1;
-			$counter{ip}=$ENV{REMOTE_ADDR};
+			$counter{ip}=$ENV{REMOTE_ADDR} if($rw ne 'r');
 			if($counter{version} eq 1) {
 				my ($_mday, $_mon, $_year) = (localtime(time-86400))[3..5];
 				my $_date = "@{[$_year+1900]}/@{[$_mon+1]}/$_mday";
@@ -169,10 +177,10 @@ sub plugin_counter_do {
 			$counter{today} = ($rw eq 'r' ? 0 : 1);
 			$counter{date} = $default{date};
 			$counter{total}++ if($rw ne 'r');
-		} elsif ($counter{ip} ne $ENV{REMOTE_ADDR} || $::CounterHostCheck eq 0) {
+		} elsif (($counter{ip} ne $ENV{REMOTE_ADDR} || $::CounterHostCheck eq 0) && $rw ne 'r') {
 			$::CounterHostCheck=1;
 			$modify = 1;
-			$counter{ip}        = $ENV{REMOTE_ADDR};
+			$counter{ip} = $ENV{REMOTE_ADDR} if($rw ne 'r');
 			$counter{today}++ if($rw ne 'r');
 			$counter{total}++ if($rw ne 'r');
 		}
@@ -182,7 +190,7 @@ sub plugin_counter_do {
 		$::counter_loaded{$hex}=%counter;
 	}
 
-	if($modify eq 1 && $rw ne 'r' || $::CounterVersion ne $counter{version}) {
+	if($modify eq 1 || $::CounterVersion ne $counter{version}) {
 		$buf="";
 		if($::CounterVersion eq 2) {
 			$buf.="date\t$counter{date}\n";
@@ -195,7 +203,7 @@ sub plugin_counter_do {
 			foreach my $keys(@keys) {
 				$buf.="$counter{$keys}\n";
 			}
-		}
+ 		}
 		Nana::File::lock_store($file,$buf);
 	}
 	$counter{total}+=0;
@@ -248,11 +256,11 @@ Count of page reference display, a part for yesterday.
 
 =item PyukiWiki/Plugin/Standard/counter
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/counter/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/counter/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/counter.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/counter.inc.pl?view=log>
 
 =back
 
@@ -266,15 +274,15 @@ L<http://nekyo.qp.land.to/>
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2004-2011 by Nekyo.
+Copyright (C) 2004-2012 by Nekyo.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
