@@ -1,16 +1,16 @@
 ######################################################################
 # img.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: img.inc.pl,v 1.89 2011/05/04 07:26:50 papu Exp $
+# $Id: img.inc.pl,v 1.421 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
-# Author: Nekyo
-# Copyright (C) 2004-2011 by Nekyo.
+# "PyukiWiki" version 0.2.0-p1 $$
+# Author: Nekyo http://nekyo.qp.land.to/
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -18,15 +18,24 @@
 ######################################################################
 # 摜\B
 # :|
-#  #img(摜URI[[,],altRg])
-# Fr,right(E) or l,left() or module(index.cgi ̌Ăяo)
+#  #img(摜URI[,][,altRg][,width,height])
+# Fr,right(E) or l,left() or center ()
+# or module(index.cgi ̌Ăяo)
 # or ȊO(NA)~
-# Pyukiwiki Classic v0.1.6b 肱̊֐ 
+# Pyukiwiki Classic v0.1.6b 肱̊֐
 # lib/wiki.cgi  img ϊłĂяo悤CB(K{)
 ######################################################################
 
+# Agif, png, jpg, jpeg łȂĂAimg ^O\
+$img::force_img_tag=0
+	if(!defined(img::force_img_tag));
+
+sub plugin_img_inline {
+	return &plugin_img_convert(@_);
+}
+
 sub plugin_img_convert {
-	my ($uri, $align, $alt) = split(/,/, shift);
+	my ($uri, $align, $alt, $width, $height) = split(/,/, shift);
 	$uri   = &trim($uri);
 	$align = &trim($align);
 	$alt   = &trim($alt);
@@ -37,23 +46,34 @@ sub plugin_img_convert {
 		$align = 'right';
 	} elsif ($align =~ /^(l|left)/i) {
 		$align = 'left';
+	} elsif ($align =~ /^(center)/i) {
+		$align = 'center';
 	} elsif ($align =~ /^module$/i) {
 		$module = 1;
-	} else {
+	} elsif ($align ne '') {
 		return '<div style="clear:both"></div>';
 	}
-#	if ($uri =~ /^(https?|ftp):/) {
-		if ($uri =~ /\.(gif|png|jpe?g)$/i) {
+#	if ($uri =~ /^(https?|ftp):/) {						# comment
+		if ($uri =~ /\.(gif|png|jpe?g)$/i || $img::force_img_tag eq 1) {
 			if ($module == 1) {
 				# Kvł΁A̕gB
 				$res .= "<a href=\"$uri\"><img src=\"$uri\" /></a>\n";
 			} else {
-				$res .= "<div style=\"float:$align; padding:.5em 1.5em .5em 1.5em;\"><img src=\"$uri\"";
+				$res .= "<div style=\"float:$align; padding:.5em 1.5em .5em 1.5em;\">"
+					if($height ne 1 && $width ne 1);
+				$res .= "<img src=\"$uri\"";
 				$res .= " alt=\"$alt\"" if ($alt ne '');
-				$res .= " /></div>\n";
+				if($width ne '' && $height ne '') {
+					$res .= " width=\"$width\" height=\"$height\"";
+				}
+				if($height ne 1 && $width ne 1) {
+					$res .= " /></div>\n";
+				} else {
+					$res .= "/>\n";
+				}
 			}
 		}
-#	}
+#	}													# comment
 	return $res;
 }
 1;
@@ -104,11 +124,13 @@ Disable a surroundings lump of a text
 
 =item PyukiWiki/Plugin/Standard/img
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/img/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/img/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/img.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/img.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/img.inc.pl?view=log>
 
 =back
 
@@ -122,17 +144,17 @@ L<http://nekyo.qp.land.to/>
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2004-2011 by Nekyo.
+Copyright (C) 2004-2012 by Nekyo.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
