@@ -1,15 +1,15 @@
 ######################################################################
 # now.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: now.inc.pl,v 1.66 2011/05/04 07:26:50 papu Exp $
+# $Id: now.inc.pl,v 1.315 2011/12/31 13:06:11 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
+# "PyukiWiki" version 0.2.0 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 by Nekyo.
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
 # License: GPL2 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
@@ -18,7 +18,6 @@
 ######################################################################
 
 use strict;
-use Time::Local;
 
 sub plugin_now_convert {
 	return &plugin_now_inline(@_);
@@ -99,11 +98,11 @@ Specification date and time. It becomes a date on the day at the time of an abbr
 
 =item PyukiWiki/Plugin/Standard/now
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/now/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/now/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/now.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/now.inc.pl?view=log>
 
 =back
 
@@ -117,15 +116,15 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2011 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
