@@ -1,86 +1,87 @@
 ######################################################################
 # pcomment.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: pcomment.inc.pl,v 1.41 2011/04/13 08:42:38 papu Exp $
+# $Id: pcomment.inc.pl,v 1.430 2012/03/01 08:41:56 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p5 $$
+# "PyukiWiki" version 0.2.0-p2 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
 
-use strict;
-
-use Digest::MD5;
-#use Digest::Perl::MD5;
+use Nana::MD5;
 
+######################################################################
 # Υեޥå
 $pcomment::format = "\x08MSG\x08 -- \x08NAME\x08 \x08NOW\x08"
 	if(!defined($pcomment::format));
-
+#
 # ̾ʤǽʤ
 $pcomment::noname = 1
 	if(!defined($pcomment::noname));
-
+#
 # ʸܤƤʤ票顼
 $pcomment::nodata = 1
 	if(!defined($pcomment::nodata));
-
-# ȤΥƥȥꥢɽ 
+#
+# ȤΥƥȥꥢɽ
 $pcomment::size_msg = 40
 	if(!defined($pcomment::size_name));
-
-# Ȥ̾ƥȥꥢɽ 
+#
+# Ȥ̾ƥȥꥢɽ
 $pcomment::size_name = 10
 	if(!defined($pcomment::size_name));
-
+#
 # Ȥ̾եޥå
 $pcomment::format_name = "\'\'[[\$1>$::resource{profile_page}/\$1]]\'\'"
 	if(!defined($pcomment::format_name));
-
+#
 # Ȥեޥå
 $pcomment::format_msg = q{$1}
 	if(!defined($pcomment::format_msg));
-
+#
 # Ȥեޥå (&new ǧǤ뤳)
 $pcomment::format_now = "Y-m-d(lL) H:i:s"
 	if(!defined($pcomment::format_now));
-
+#
 # ǥեȤΥȥڡ
 $pcomment::comment_page = "$::resource{comment_page}/\$1"
 	if(!defined($pcomment::comment_page));
-
+#
 # ǥեȤκǿɽ
 $pcomment::num_comments = 10
 	if(!defined($pcomment::num_comments));
-
+#
 # Ƥ1:above(Ƭ)/0:below()Τɤ뤫
 $pcomment::direction_default=1
 	if(!defined($pcomment::direction_default));
-
+#
 # 0:ʤ/1:֥ڡΥॹ׹/2:ȥڡΥॹ׹/3:ξ
 $pcomment::timestamp=2
 	if(!defined($pcomment::timestamp));
-
+#
 # 0:񤭹߸女ȥڡ/1:񤭹߸֥ڡ
 $pcomment::viewcommentpage=1
 	if(!defined($pcomment::viewcommentpage));
-
+#
 # 1:ȥڡ뤷֤ˤƤʥեफϽ񤭹߲ǽǤ
 $pcomment::frozencommentpage=1
 	if(!defined($pcomment::frozencommentpage));
+######################################################################
+
+use strict;
 
 sub plugin_pcomment_action {
-	&::spam_filter($::form{mymsg}, 2);
-	&::spam_filter($::form{myname}, 0);
+	&::spam_filter($::form{mymsg}, 2, $::chk_article_uri_count, $::chk_article_mail_count);
+	&::spam_filter($::form{myname}, 0, $::chk_article_uri_count, $::chk_article_mail_count);
 
 	if (($::form{mymsg} =~ /^\s*$/ && $pcomment::nodata eq 1)
 	 || ($::form{myname} =~ /^\s*$/ && $pcomment::noname eq 1)
@@ -88,7 +89,7 @@ sub plugin_pcomment_action {
 		return('msg'=>"$::form{mypage}\t\t$::resource{pcomment_plugin_err}",'body'=>&text_to_html($::database{$::form{mypage}}),'ispage'=>1);
 	}
 
-	# ȹԤ
+	# ȹԤ										# comment
 	my $datestr = ($::form{nodate} == 1) ? '' : &date($pcomment::format_now);
 	my $__name=$pcomment::format_name;
 	$__name=~s/\$1/$::form{myname}/g;
@@ -103,7 +104,7 @@ sub plugin_pcomment_action {
 	$pcomment =~ s/\x08NOW\x08/$_now/;
 	$pcomment = "-" . $pcomment;
 
-	# ȥڡβ
+	# ȥڡβ									# comment
 	my ($i, @pcomments)=&plugin_pcomment_get($::form{page},0,$::form{above});
 	if($::form{reply} eq '') {
 		if($::form{above}) {
@@ -127,27 +128,26 @@ sub plugin_pcomment_action {
 		}
 		@pcomments=@tmp;
 	}
-	# 
+	# 													# comment
 	my $postdata=join("\n"
 		, sprintf($::resource{pcomment_plugin_commentpage_title},$::form{mypage})
 		, sprintf($::resource{pcomment_plugin_commentpage_backlink},$::form{mypage},$::form{mypage})
 		, @pcomments);
 
-	# ȥڡ¸ߤʤΤߡ
+	# ȥڡ¸ߤʤΤߡ				# comment
 	if($pcomment::frozencommentpage eq 1) {
 		if(&get_info($::form{page}, $::info_CreateTime)+0 eq 0) {
 			&set_info($::form{page}, $::info_IsFrozen, 1);
 		}
 	}
 	if ($::form{mymsg}) {
-		# ڡΥॹ
+		# ڡΥॹ							# comment
 		if($pcomment::timestamp % 2) {
 			&set_info($::form{mypage}, $::info_UpdateTime, time);
 			&set_info($::form{mypage}, $::info_LastModifiedTime, time);
 			&update_recent_changes;
-$::debug.="1 $::form{mypage}\n";
 		}
-		# ȥڡΥॹ
+		# ȥڡΥॹ					# comment
 		if(int($pcomment::timestamp / 2)
 				|| &get_info($::form{page}, $::info_CreateTime)+0 eq 0) {
 			my $pushpage=$::form{mypage};
@@ -158,7 +158,6 @@ $::debug.="1 $::form{mypage}\n";
 			}
 			$::form{mypage}=$::form{page};
 			&update_recent_changes;
-$::debug.="2 $::form{mypage}\n";
 			$::form{mypage}=$pushpage;
 		}
 		$::form{mymsg} = $postdata;
@@ -166,11 +165,9 @@ $::debug.="2 $::form{mypage}\n";
 		if($pcomment::viewcommentpage eq 1) {
 			my $basepage=$::form{mypage};
 			$::form{mypage}=$::form{page};
-$::debug.="3 $::form{mypage} $basepage\n";
 			&do_write("FrozenWrite",$basepage);
 		} else {
 			$::form{mypage}=$::form{page};
-$::debug.="4 $::form{mypage}\n";
 			&do_write("FrozenWrite");
 		}
 	} else {
@@ -195,7 +192,7 @@ sub plugin_pcomment_convert {
 	my $pcomment_page;
 	my $pcomment_msgs;
 
-	# ץ
+	# ץ										# comment
 	foreach (@argv) {
 		chomp;
 		if (/below/) {
@@ -216,17 +213,17 @@ sub plugin_pcomment_convert {
 		}
 	}
 
-	# ǥեȤΥȥڡꡩ
+	# ǥեȤΥȥڡꡩ					# comment
 	if($pcomment_page eq '') {
 		$pcomment_page=$pcomment::comment_page;
 		$pcomment_page=~s/\$1/$::form{mypage}/g;
 	}
-	# ǥեȤɽԿꡩ
+	# ǥեȤɽԿꡩ							# comment
 	if($pcomment_msgs+0 <= 0) {
 		$pcomment_msgs = $pcomment::num_comments;
 	}
 
-	# ץӥ塼륳Ȥɤ߹
+	# ץӥ塼륳Ȥɤ߹						# comment
 	my ($i, @pcomments)=&plugin_pcomment_get($pcomment_page,$pcomment_msgs,$above);
 	my $pcomment_info;
 	my $pcomments;
@@ -381,7 +378,7 @@ do error of no pcomment
 
 Colums of comment textarea.
 
-=item $pcomment::size_name 
+=item $pcomment::size_name
 
 Colums of name textarea.
 
@@ -439,11 +436,13 @@ The screen changes after writing are specified.
 
 =item PyukiWiki/Plugin/Standard/pcomment
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/pcomment/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/pcomment/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/pcomment.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/pcomment.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/pcomment.inc.pl?view=log>
 
 =back
 
@@ -457,17 +456,17 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2011 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
