@@ -1,16 +1,16 @@
 ######################################################################
 # setting.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: setting.inc.pl,v 1.65 2011/05/04 07:26:50 papu Exp $
+# $Id: setting.inc.pl,v 1.449 2012/03/01 08:41:56 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p5 $$
+# "PyukiWiki" version 0.2.0-p2 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -23,15 +23,18 @@
 
 sub plugin_setting_action {
 	my $body;
-# bug ? 0.1.8 fix
-#	return if($::setting_cookie eq '' || $::write_location eq 0);
-# 0.1.9 fix
+# bug ? 0.1.8 fix										# comment
+#	return if($::setting_cookie eq '' || $::write_location eq 0);	# comment
+# 0.1.9 fix												# comment
+
 	return if($::useExPlugin eq 1 && $::_exec_plugined{setting} ne 2);
 	if($::form{submit} ne '') {
 		my @http_headers=();
 		push(@http_headers, "Status: 302");
 		if($::form{refer} ne '') {
 			push(@http_headers, "Location: $::basehref?@{[&encode($::form{refer})]}");
+		} elsif($::form{mypage} ne '') {
+			push(@http_headers, "Location: $::basehref?@{[&encode($::form{mypage})]}");
 		} else {
 			push(@http_headers, "Location: $::basehref?cmd=setting");
 		}
@@ -54,7 +57,7 @@ sub plugin_setting_action {
 					$flg=1 if($v eq $::form{"_" . $setting});
 				}
 				if($flg eq 0) {
-					$body.="err:$setting<br>";
+					$body.="err:$setting<br />";
 				} else {
 					$::setting_cookie{$setting}=$::form{"_" . $setting};
 				}
@@ -71,8 +74,9 @@ sub plugin_setting_action {
 	$body.=<<EOM;
 <h3>$::resource{plugin_setting_title}</h3>
 <form action="$::script" method="POST">
-<input type="hidden" name="cmd" value="setting">
-<input type="hidden" name="refer" value="$::form{refer}">
+<input type="hidden" name="cmd" value="setting" />
+<input type="hidden" name="refer" value="$::form{refer}" />
+<input type="hidden" name="mypage" value="$::form{mypage}" />
 <table>
 EOM
 	foreach my $setting(split(/,/,$::resource{plugin_setting_list})) {
@@ -114,12 +118,12 @@ EOM
 					$value=$_;
 				}
 				if($::setting_cookie{$setting} ne '') {
-					$checked=" checked" if($value eq $::setting_cookie{$setting});
+					$checked=qq( checked="checked") if($value eq $::setting_cookie{$setting});
 				} else {
-					$checked=" checked" if($value eq $default);
+					$checked=qq( checked="checked") if($value eq $default);
 				}
 				$opts.=<<EOM;
-<input type="radio" name="_$setting" value="$value"$checked>$name
+<input type="radio" name="_$setting" value="$value"$checked />$name
 EOM
 			}
 			$body.=<<EOM;
@@ -128,7 +132,7 @@ EOM
 		}
 	}
 	$body.=<<EOM;
-<tr><td>&nbsp;</td><td><input type="submit" name="submit" value="$::resource{plugin_setting_button}"></td></tr>
+<tr><td>&nbsp;</td><td><input type="submit" name="submit" value="$::resource{plugin_setting_button}" /></td></tr>
 </table>
 </form>
 EOM
@@ -216,17 +220,21 @@ To the beginning   When there is a character string called sub, it is after it.
 
 =item PyukiWiki/Plugin/Admin/setting
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Admin/setting/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Admin/setting/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/setting.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/setting.inc.pl?view=log>
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/setting.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/setting.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/setting.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/lib/setting.inc.pl?view=log>
 
 =back
 
-=head1 AUTHOR
+=head1 
 
 =over 4
 
@@ -236,17 +244,17 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
-=head1 LICENSE
+=head1 饤
 
-Copyright (C) 2005-2011 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
