@@ -1,16 +1,16 @@
 ######################################################################
 # sitemap.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: sitemap.inc.pl,v 1.92 2011/05/04 07:26:50 papu Exp $
+# $Id: sitemap.inc.pl,v 1.424 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
+# "PyukiWiki" version 0.2.0-p1 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -38,7 +38,7 @@
 #
 # Ȥ
 # ?cmd=sitemap
-# http://pyukiwiki.sourceforge.jp/?cmd=sitemap
+# /?cmd=sitemap
 #
 ######################################################################
 
@@ -66,14 +66,14 @@ sub plugin_sitemap_action {
 	$::form{level}=5 if($::form{level}+0 eq 0);
 
 	foreach $basepage(split(/\n/,$::database{$menubar})) {
-		# MenuBar ***ιܤФ
+		# MenuBar ***ιܤФ					# comment
 		if ($basepage=~/^(\*{1,5})(.+)/) {
 			$name=$basepage;
 			$name=~s/^(\*{1,5})//g;
 			$name=&plugin_sitemap_trim($name);
 			$menucount++;
 			push(@sitemap,$name);
-		#  MenuBar֥饱åȤФ
+		#  MenuBar֥饱åȤФ					# comment
 		}elsif($basepage=~/$::bracket_name/ && $basepage!~/>(http:|https:|ftp:|mailto:|\?)/
 			&& $basepage!~/($::interwiki_name1|$::interwiki_name2)/) {
 			$basepage=~s/$::bracket_name/$1/g;
@@ -82,7 +82,7 @@ sub plugin_sitemap_action {
 			if(&is_readable($basepage)) {
 				$submenu++;
 				$sitemap{$name}.=sprintf("%05d\t%05d\t%05d\t%05d\t%s\n",$menucount,$submenu,0,0,$basepage);
-				# MenuBarФڡ顢٥ΥڡФ
+				# MenuBarФڡ顢٥ΥڡФ	# comment
 				$sitemap{$name}.=&submenu($basepage,$menucount,$submenu,0,1);
 			}
 		}
@@ -153,10 +153,10 @@ sub submenu {
 			$nextmenu++;
 			$ret.=sprintf("%05d\t%05d\t%05d\t%05d\t%s\n",$menucount,$submenu,$nextmenu,$nest,$nextpage);
 			$ret.=&submenu($nextpage,$menucount,$submenu,$nextmenu+1,$nest+1);
-		# include
+		# include											# comment
 		} elsif($line=~/^#include\((.*?)\)/ && $::form{include} eq '') {
 			$ret.=&submenu((split(/,/,$1))[0],$menucount+1,$submenu,$nextmenu+1,$nest)
-		# ls2
+		# ls2												# comment
 		}elsif(($line=~/^#ls2\((.*?)\)/ || $line=~/^#ls2/) && $::form{ls2} eq '') {
 			my @ls2args = split(/,/, $1);
 			my $ls2prefix;
@@ -189,7 +189,7 @@ sub submenu {
 sub plugin_sitemap_trim {
 	my($str,$strlen)=@_;
 
-	$Zspace = '(?:\xA1\xA1)'; # ѥڡ
+	$Zspace = '(?:\xA1\xA1)'; # ѥڡ		# comment
 	$eucpre = qr{(?<!\x8F)};
 
 	if($strlen+0 > 0) {
@@ -201,9 +201,9 @@ sub plugin_sitemap_trim {
 		$str.="..." if($len ne length($str));
 	}
 
-	# $str Ƭζʸ(ѥڡ)
-	$str =~ s/^(?:\s|$Zspace)+//o; # $str  EUC-JP ξ
-	$str =~ s/$eucpre(?:\s|$Zspace)+$//o; # $str  EUC-JP ξ(perl5.005ʹ)
+	# $str Ƭζʸ(ѥڡ)	# comment
+	$str =~ s/^(?:\s|$Zspace)+//o; # $str  EUC-JP ξ	# comment
+	$str =~ s/$eucpre(?:\s|$Zspace)+$//o; # $str  EUC-JP ξ(perl5.005ʹ	# comment)
 	$str=~s/\~//g;
 	$str=~s/[\r|\n]//g;
 	$str=~s/\ \/\/\ \#.*//g;	# debug
@@ -267,11 +267,13 @@ The page registered into MenuBar describes as follows.
 
 =item PyukiWiki/Plugin/Standard/sitemap
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/sitemap/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/sitemap/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/sitemap.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/sitemap.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/sitemap.inc.pl?view=log>
 
 =back
 
@@ -285,17 +287,17 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2011 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
