@@ -1,16 +1,16 @@
 ######################################################################
 # topicpath.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: topicpath.inc.pl,v 1.63 2011/05/04 07:26:50 papu Exp $
+# $Id: topicpath.inc.pl,v 1.477 2012/03/18 11:23:51 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Junichi http://www.re-birth.com/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -25,7 +25,7 @@
 ######################################################################
 # Re-Birth Original
 #$topicpath::AutoLoad=1					if(!defined($topicpath::AutoLoad));
-#$topicpath::SEPARATOR = '/'			if(!defined($topicpath::SEPARATOR));
+#$topicpath::SEPARATOR = $::separator	if(!defined($topicpath::SEPARATOR));
 #$topicpath::FRONTMARK = '  '			if(!defined($topicpath::FRONTMARK));
 #$topicpath::ARROW = ' &gt; '			if(!defined($topicpath::ARROW));
 #$topicpath::FRONTPAGE = $::FrontPage	if(!defined($topicpath::FRONTPAGE));
@@ -35,7 +35,7 @@
 ######################################################################
 # PukiWiki Like
 $topicpath::AutoLoad=1					if(!defined($topicpath::AutoLoad));
-$topicpath::SEPARATOR = '/'				if(!defined($topicpath::SEPARATOR));
+$topicpath::SEPARATOR = $::separator	if(!defined($topicpath::SEPARATOR));
 $topicpath::FRONTMARK = ' /  '			if(!defined($topicpath::FRONTMARK));
 $topicpath::ARROW = ' / '				if(!defined($topicpath::ARROW));
 $topicpath::FRONTPAGE = $::FrontPage	if(!defined($topicpath::FRONTPAGE));
@@ -45,7 +45,7 @@ $topicpath::SUFFIX = ''					if(!defined($topicpath::SUFFIX));
 ######################################################################
 
 sub plugin_topicpath_inline {
-	# wiki.cgiɤ߹ߤȽǤ
+	# wiki.cgiɤ߹ߤȽǤ				# commnt
 	my($wikicgiflag,$page)=split(/,/, shift);
 	return '' if(shift eq 1 && $topicpath::AutoLoad eq 0);
 
@@ -57,7 +57,7 @@ sub plugin_topicpath_inline {
 
 	my @path_array = split($topicpath::SEPARATOR,$mypage);
 
-	# FrontPageΥå
+	# FrontPageΥå										# commnt
 	$topicpath::FRONTPAGEUrl = &createUrl($topicpath::FRONTPAGE, $topicpath::FRONTPAGE, $topicpath::FRONTPAGE, $topicpath::FRONTPAGENAME);
 
 	if($mypage eq $topicpath::FRONTPAGE) {
@@ -76,25 +76,25 @@ sub plugin_topicpath_inline {
 
 		$result .= &createUrl($pagename, $pathname, $topicpath::FRONTPAGE, $topicpath::FRONTPAGENAME);
 
-		# Ĥ fix 0.2.0
+		# Ĥ fix 0.2.0								# commnt
 		$result .= $topicpath::ARROW;
 	}
-	# Ǹ
+	# Ǹ										# commnt
 	$result =~s/$topicpath::ARROW$//g;
 
 	return $topicpath::PREFIX . $result . $topicpath::SUFFIX;
 }
 
-# ex.
-# $pagename : Page
-# $pathname : Category/Page
+# ex.														# commnt
+# $pagename : Page											# commnt
+# $pathname : Category/Page									# commnt
 sub createUrl() {
 	my ($pagename,$pathname, $FRONTPAGE, $FRONTPAGENAME) = @_;
 
 	if(&is_exist_page($pathname)) {
 		return qq|<a href="@{[&make_cookedurl(&encode($pathname))]}">@{[&escape($pagename eq $FRONTPAGE ? $FRONTPAGENAME : $pagename)]}</a>|;
 	} else {
-		return qq|@{[&escape($pagename)]}<a href="$::script?cmd=edit&mypage=@{[&encode($pathname)]}">?</a>|;
+		return qq|@{[&escape($pagename)]}<a href="$::script?cmd=edit&amp;mypage=@{[&encode($pathname)]}">?</a>|;
 	}
 }
 
@@ -125,11 +125,13 @@ Page name   It indicates by the class by /(slash) pause, and links to each page.
 
 =item PyukiWiki/Plugin/Admin/topicpath
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Admin/topicpath/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Admin/topicpath/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/topicpath.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/topicpath.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/topicpath.inc.pl?view=log>
 
 =item Site manufacture/PyukiWiki/Plugin/topicpath
 
@@ -149,17 +151,17 @@ L<http://www.re-birth.com/>
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2011 by Junichi.
+Copyright (C) 2005-2012 by Junichi.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
