@@ -1,15 +1,15 @@
 ######################################################################
 # yetlist.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: yetlist.inc.pl,v 1.47 2011/05/04 07:26:50 papu Exp $
+# $Id: yetlist.inc.pl,v 1.296 2011/12/31 13:06:11 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
+# "PyukiWiki" version 0.2.0 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 by Nekyo.
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
 # License: GPL2 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@ sub plugin_yetlist_action {
 			$chunk=&unarmor_name($chunk);
 			($chunk1,$chunk2) = split(/[:>]/,$chunk);
 			$chunk=$chunk2 eq '' ? $chunk1 : $chunk2;
-			# local wiki page
+			# local wiki page							# comment
 			if(&is_exist_page($chunk) || $chunk eq '') {
 				next;
 			}
@@ -92,7 +92,7 @@ The page which is not made yet is a page which is specified by WikiName or Brack
 
 =head1 WARNING
 
-A large amount of key words not to make the parameter name of a name and similar WikiName of the guest described in the comment a page easily on an actual operation side are caught though very Wiki in the point that someone excluding me might write the page. 
+A large amount of key words not to make the parameter name of a name and similar WikiName of the guest described in the comment a page easily on an actual operation side are caught though very Wiki in the point that someone excluding me might write the page.
 
 =head1 SEE ALSO
 
@@ -100,11 +100,11 @@ A large amount of key words not to make the parameter name of a name and similar
 
 =item PyukiWiki/Plugin/Standard/yetlist
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/yetlist/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/yetlist/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/yetlist.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/yetlist.inc.pl?view=log>
 
 =back
 
@@ -118,15 +118,15 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2011 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
